<?php

namespace Teknisa\EST\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;


class Est33000RequisicaoEstoqueController extends \Teknisa\EST\Controllers\TeknisaCrud {
	protected $dataSourceName = '';
	protected $parameterBagColumns = array('');
    protected $est33000requisicaoestoqueservice;

    public function __construct($crudService, $parameterBag,$est33000requisicaoestoqueservice) {
        parent::__construct($crudService, $parameterBag);
        $this->est33000requisicaoestoqueservice = $est33000requisicaoestoqueservice;
    }

	public function findRequisicaoEstoque(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'requesto_completa' ;
            $this->parameterBagColumns =  array("CDLOCALORIG","CDSETOR","CDLOCALDEST","P_DTPREVFIN","P_TCDSETOR","P_DTREQUINI","P_DTREQUFIN","CDALMOXDEST","CDFILIAL","P_DTPREVINI","CDALMOXORIG","IDSTATUSREQ");
            parent::find($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function findItemRequisicaoEstoque(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'itrequesto_produto_itlanctoest' ;
            $this->parameterBagColumns =  array("P_CDFILIAL","P_NRREQUESTO");
            parent::find($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function findLote(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'lote_marca_posestatu' ;
            $this->parameterBagColumns =  array("P_CDFILIAL","P_NRLOTEESTQ","P_CDPRODUTO");
            parent::find($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function saveRequisicao(DTO\Request $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'requesto';
            parent::save($request,$response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function updateProduto(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getDataSet()->getRows()[0];
	        $this->dataSourceName = 'itrequesto_produto_itlanctoest' ;
            if($row["__is_new"]){
                parent::save($request,$response);
            } else {
                $this->est33000requisicaoestoqueservice->updateProduto($row);
            }
            
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function saveNovaRequisicao(DTO\Request $request, DTO\Response $response) {
        try {
            $requisicao = $request->getRow()['requisicao'];
            $produtos = $request->getRow()['produtos'];
            
            $arrayRequisicao[] = $requisicao;
            $dataSetRequisicao = new DataSet('requesto_completa', $arrayRequisicao);
            $requestRequisicao = new DTO\Request\DataSet($dataSetRequisicao, $request->getMethod(),$request->getRoutePath(), $request->getUserId());
            $rowRequsicao = $this->crudService->getRowsToSave($requestRequisicao,'requesto');
            
            if(is_array($produtos))
                $arrayProdutos = $produtos;
            else 
                $arrayProdutos[] = $produtos;
            
            $dataSetProdutos = new DataSet('itrequesto_produto_itlanctoest', $arrayProdutos);
            
            $requestProdutos = new DTO\Request\DataSet($dataSetProdutos, $request->getMethod(),$request->getRoutePath(), $request->getUserId());

            $rowProdutos = $this->crudService->getRowsToSave($requestProdutos,'itrequesto');
            
            $dataSet = $this->est33000requisicaoestoqueservice->salvarNovaRequisicao($rowRequsicao,$rowProdutos);
            
            $response->addDataSet($dataSet);

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function saveNovoProduto(DTO\Request $request, DTO\Response $response) {
        try {
            $rowProduto = $this->crudService->getRowsToSave($request,'itrequesto');
            $dataSet = $this->est33000requisicaoestoqueservice->salvarNovoProduto($rowProduto[0]);
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deleteProduto(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $dataSet = $this->est33000requisicaoestoqueservice->deletarProduto($row);
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deleteRequisicao(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $this->est33000requisicaoestoqueservice->deletarRequisicao($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function importProducts(Filter $request, Response $response){
        try {
            error_reporting(E_ALL);
            ini_set('display_errors', 1);
            $params = $request->getParameters();
            $tela = isset($params['origin'])? $params['origin']['containerLabel'] : 'ajuste';
            $newResponse = new Response();
            $params  = $request->getParameters();
            foreach($params['filter'] as $rowFilter){
                if($rowFilter['name'] == 'CDFILIAL')
                    $filial = $rowFilter['value'];
            }

            $this->parameterBagColumns = ['CDGRUPPROD', 'CDORDENA', 'CDFILIAL', 'CDALMOXARIFE', 'CDLOCALESTOQ', 'NRLOTEESTQ', 'NRSUBLOTE', 'IDORDEMCLC', 'DTLANCMOVI', 'IDGRUPPROD', 'CDSEGMER'];
            $filterCriteria = $request->getFilterCriteria();
            $cdSegMerc = $this->service->getCdSegMercFilial($filial);
            $filterCriteria->addCondition('CDSEGMER', $cdSegMerc);
            
            $paramFilial = $this->service->getParamFilial($filial);
            if($paramFilial->getIdutilalmox() == 'S'){
                $codAlmox = $paramFilial->getCdalmoxarife();
                if(is_null($codAlmox))
                    throw new \Exception("Unidade Controla almoxarifado e não existe almoxarifado padrão parametrizado.",400);
            }
            if($paramFilial->getIdutillcestq() == 'S'){
                $codLocal = $paramFilial->getCdlocalestoq();
                if(is_null($codLocal))
                    throw new \Exception("Unidade Controla localização e não existe local padrão parametrizado.",400);
            }
            
            if($tela == 'Implantação de Estoque'){
                $this->dataSourceName = 'implantacao_import_products';
                array_push($this->parameterBagColumns, 'CUSTLIQU');
                array_push($this->parameterBagColumns, 'CUSTBRUT');
                $paramCustos = $this->service->getParamCustos($filial);
                $filterCriteria->addCondition('CUSTLIQU', $paramCustos['CUSTLIQU']);
                $filterCriteria->addCondition('CUSTBRUT', $paramCustos['CUSTBRUT']);
            }else{
                $estNeg = $paramFilial->getIdpermestneg();
                if($estNeg == 'S')
                    $this->dataSourceName = 'ajuste_import_products_neg';
                else
                    $this->dataSourceName = 'ajuste_import_products';
            }
            
            parent::find($request, $newResponse);
            
            $arrReponse = count($newResponse->getDataSets()) > 0? $newResponse->getDataSets()[0]->getRows() : $newResponse->getDataSets();
            if($tela == 'Implantação de Estoque'){
                if(count($arrReponse) > 0 && $arrReponse[0]['FILIUTLOTE'] == 'S' && $arrReponse[0]['IDENTRAUTLOTE'] == 'S'){
                    $requestFilter =  $request->getFilterCriteria()->getConditions();
                    foreach($requestFilter as $rowFilter){
                        if($rowFilter['columnName'] == 'DTLANCMOVI')
                            $dtlanc = $rowFilter['value'];
                    }
                    foreach($arrReponse as $key => &$rowar){
                        if($rowar['UTLOTE'] == 'S'){
                            try{
                                $lote = $this->infComplService->executaProcedurePrxLoteProdEst($rowar['CDFILIAL'], $dtlanc, $rowar['CDPRODMOVI']);
                                if(is_null($lote)){
                                    throw new \Exception("Unidade Controla lote e não existe minemonicos parametrizados",400);
                                }
                                $rowar['NRLOTEESTQ'] = $lote;
                            }
                            catch (\Exception $e) {
                                $response->setError(new Error($e->getMessage(), 500));
                            }
                        }
                    }
                }
            }
            /*
            //Caso futuramente decida-se validar se todos produtos possuem custo no momento da importação, descomentar e terminar o código abaixo (este processo aumentara significamente o tempo de respota desta request)
            $requestFilter =  $request->getFilterCriteria()->getConditions();
            $dtlanc = '';
            foreach($requestFilter as $rowFilter){
                if($rowFilter['columnName'] == 'DTLANCMOVI')
                    $dtlanc = $rowFilter['value'];
            }
            
            $products = $newResponse->getDataSets()[0]->getRows();
            
            $itensImplantacao = [];
            $itensAjuste = [];
            
            foreach($products as &$produto){
                $produto["CUSTO"] = $this->service->validaCustoAjuste($produto["CDFILIAL"], $produto["CDPRODUTO"], $dtlanc, $produto["CDALMOXARIFE"], $produto["CDLOCALESTOQ"], $produto["NRLOTEESTQ"], $produto["NRSUBLOTE"], null);
                
                if($produto["CUSTO"] == 0){
                    $itensImplantacao[] = $produto;
                    $this->service->insertLoteProduto($produto);
                } else{
                    $itensAjuste[] = $produto;
                }
            }*/
            $response->addDataSet(new DataSet("products", $arrReponse));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }

        $this->dataSourceName = 'lanctoestoq_ajuste';
        $this->parameterBagColumns = ['IDTPLANCTO','CDFILIAL'];
    }
    
    public function importProductsPorFilial(Filter $request, Response $response) {
        try {
            $this->parameterBagColumns = [ 'CDORDENA', 'P_CDFILIAL', 'P_DATAPROC', 'DTLANCESTQ', 'CDSEGMER'];
            $params = $request->getParameters();
            $tela = isset($params['origin'])? $params['origin']['containerLabel'] : 'ajuste';
            foreach($params['filter'] as $rowFilter){
                if($rowFilter['name'] == 'P_CDFILIAL')
                    $filial = $rowFilter['value'];
            }
            
            $filterCriteria = $request->getFilterCriteria();
            $cdSegMerc = $this->service->getCdSegMercFilial($filial);
            $filterCriteria->addCondition('CDSEGMER', $cdSegMerc);
            
            $paramFilial = $this->service->getParamFilial($filial);
            if($paramFilial->getIdutilalmox() == 'S'){
                $codAlmox = $paramFilial->getCdalmoxarife();
                if(is_null($codAlmox))
                    throw new \Exception("Unidade Controla almoxarifado e não existe almoxarifado padrão parametrizado.",400);
            }
            if($paramFilial->getIdutillcestq() == 'S'){
                $codLocal = $paramFilial->getCdlocalestoq();
                if(is_null($codLocal))
                    throw new \Exception("Unidade Controla localização e não existe local padrão parametrizado.",400);
            }
            
            if($tela == 'Implantação de Estoque'){
                $this->dataSourceName = 'implantacao_import_products_filial';
                array_push($this->parameterBagColumns, 'CUSTLIQU');
                array_push($this->parameterBagColumns, 'CUSTBRUT');
                $paramCustos = $this->service->getParamCustos($filial);
                $filterCriteria->addCondition('CUSTLIQU', $paramCustos['CUSTLIQU']);
                $filterCriteria->addCondition('CUSTBRUT', $paramCustos['CUSTBRUT']);
            }else{
                $estNeg = $paramFilial->getIdpermestneg();
                if($estNeg == 'S')
                    $this->dataSourceName = 'ajuste_import_products_filial_neg';
                else    
                    $this->dataSourceName = 'ajuste_import_products_filial';
            }
            
            
            $newResponse = new Response();
            
            parent::find($request, $newResponse);
           
            $arrReponse = count($newResponse->getDataSets()) > 0? $newResponse->getDataSets()[0]->getRows() : $newResponse->getDataSets();
            
            
            if($tela == 'Implantação de Estoque'){
                if(count($arrReponse) > 0 && $arrReponse[0]['FILIUTLOTE'] == 'S'){
                    
                    $requestFilter =  $request->getFilterCriteria()->getConditions();
                    foreach($requestFilter as $rowFilter){
                        if($rowFilter['columnName'] == 'DTLANCMOVI' || $rowFilter['columnName'] == 'DTLANCESTQ')
                            $dtlanc = $rowFilter['value'];
                    }
                    foreach($arrReponse as $key => &$rowar){
                        if($rowar['UTLOTE'] == 'S'){
                            try{
                                $lote = $this->infComplService->executaProcedurePrxLoteProdEst($rowar['CDFILIAL'], $dtlanc, $rowar['CDPRODMOVI']);
                                if(is_null($lote)){
                                    throw new \Exception("Unidade Controla lote e não existe minemonicos parametrizados",400);
                                }
                                $rowar['NRLOTEESTQ'] = $lote;
                            }   
                            catch (\Exception $e) {
                                $response->setError(new Error($e->getMessage(), 500));
                            }
                        }
                    }
                }
            }
            
            $response->addDataSet(new DataSet("products", $arrReponse));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }

        $this->dataSourceName = 'lanctoestoq_ajuste';
        $this->parameterBagColumns = ['IDTPLANCTO','CDFILIAL'];
    }
    
    public function importProductsPosicao(Filter $request, Response $response) {
        try {
            $this->parameterBagColumns = [ 'CDORDENA', 'CDFILIAL', 'DTPOSICAO','DATAPROC'];
            $params = $request->getParameters();
            $this->dataSourceName = 'ajuste_import_products_posicao';
            
            $newResponse = new Response();
            
            parent::find($request, $newResponse);
           
            $arrReponse = count($newResponse->getDataSets()) > 0? $newResponse->getDataSets()[0]->getRows() : $newResponse->getDataSets();
            
            $response->addDataSet(new DataSet("products", $arrReponse));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
        
        $this->dataSourceName = 'lanctoestoq_ajuste';
        $this->parameterBagColumns = ['IDTPLANCTO','CDFILIAL'];

    }


}