<?php

namespace Teknisa\EST\Factories;

use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Est57000TransferenciaEstoqueFactory {
    protected $connection;
    protected $entityManager;

    public function __construct($entityManager) {
        $this->entityManager = $entityManager;
        $this->connection    = $entityManager->getConnection();
    }

    public function findDataProcessamento($nrorg, $cdfilial) {
        $sql = "SELECT DECODE(PG.IDUTILDTPROC,'S',DECODE(PF.DTPROCESSA, NULL, TO_CHAR(TO_DATE(SYSDATE), 'DD/MM/YYYY'), PF.DTPROCESSA), TO_CHAR(TO_DATE(SYSDATE), 'DD/MM/YYYY')) AS DTPROCESSA
                FROM  PARAMGERAL PG ,PARAMFILIAL PF
                WHERE
                    PF.CDFILIAL = :CDFILIAL AND
                    PF.NRORG    = :NRORG    AND
                    PG.NRORG    = :NRORG";
        $params = array(
            'NRORG'=>$nrorg,
           'CDFILIAL'=>$cdfilial
        );

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function buscaTipoCustoFilial($nrorg, $cdfilial) {
        $sql = "SELECT NVL(CDTIPCUSTEST,3) AS CDTIPCUSTEST
                FROM PARAMFILIAL
                WHERE
                    CDFILIAL = :P_CDFILIAL AND
                    NRORG    = :P_NRORG";
        $params = array(
           'P_NRORG'=>$nrorg,
           'P_CDFILIAL'=>$cdfilial
        );

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function geraNrsequitem($nrorg, $cdfilial,$nrlancestq) {
        $sql = "SELECT NVL  (         LPAD(TO_CHAR(MAX(NRSEQUITEM) + 1),4,'0')  ,  LPAD(TO_CHAR(1),4,'0' ) ) AS NRSEQUITEM
                FROM ITLANCTOEST
                WHERE
                    CDFILIAL = :P_CDFILIAL
                    AND NRLANCESTQ = :P_NRLANCESTQ";

        $params = array(
            'P_CDFILIAL'=>$cdfilial,
            'P_NRLANCESTQ'=>$nrlancestq,
        );

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function buscaProdutosRequisicao($nrorg, $cdfilial,$nrrequesto) {
        $sql = "SELECT
                    I.CDFILIAL,
                    I.NRREQUESTO,
                    I.CDPRODUTO,
                    I.QTREQUESTO,
                    I.QTDEVOREQU,
                    I.IDSTITREQU,
                    I.CDFILILANC,
                    I.NRLANCESTQ,
                    I.NRSEQUITEM,
                    I.NRLOTEESTQ,
                    I.NRSUBLOTE,
                    P.CDARVPROD,
                    P.SGUNIDADE,
                    P.VRFATOCONV,
                    P.CDPRODESTO,
                    I.QTREQUESTO AS QTTOTLANCTO
                FROM ITREQUESTO I,
                    PRODUTO P
                WHERE
                    I.CDPRODUTO  = P.CDPRODUTO AND
                    I.NRORG      = P.NRORG AND
                    I.CDFILIAL   = :P_CDFILIAL AND
                    I.NRREQUESTO = :P_NRREQUESTO AND
                    I.NRORG     = :P_NRORG ";

        $params = array(
            'P_NRORG'=>$nrorg,
            'P_CDFILIAL'=>$cdfilial,
            'P_NRREQUESTO'=>$nrrequesto,
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function gerarValorUnitario($cdfilial,$cdproduto,$nrtipocusto,$dtreferencia,$dtatual,$cdalmoxarife,$cdlocalestoq,$nrlote,$nrsublote){
        
            
        $sql = "SELECT NVL(CUSTO_PRODUTO_LCEST(:P_CDFILIAL, :P_CDPRODUTO , :P_NRTIPOCUSTO, :P_DTREFERENCIA, :P_DTATUAL, :P_ALMOXARIFE, :P_LOCALESTOQ, :P_NRLOTEESTQ, :P_NRSUBLOTE),0) AS VRCUSTO FROM DUAL";
        $params = array(
            'P_CDFILIAL'=>$cdfilial,
            'P_CDPRODUTO'=>$cdproduto,
            'P_NRTIPOCUSTO'=>$nrtipocusto,
            'P_DTREFERENCIA'=>$dtreferencia,
            'P_DTATUAL'=>$dtatual,
            'P_ALMOXARIFE'=>$cdalmoxarife,
            ':P_LOCALESTOQ'=>$cdlocalestoq, 
            ':P_NRLOTEESTQ'=>$nrlote, 
            ':P_NRSUBLOTE'=>$nrsublote
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getAlmoxRequisicao($nrrequesto, $cdfilial) {
        $sql = "SELECT A.CDALMOXARIFE AS CDALMOXENTR, A.DSALMOXARIFE AS DSALMOXENTR, A.CDLOCALESTOQ AS CDLESTQENTR, A.DSLOCALESTOQ AS DSLESTQENTR, B.CDALMOXARIFE AS CDALMOXSAIDA, B.DSALMOXARIFE AS DSALMOXSAIDA, B.CDLOCALESTOQ AS CDLESTQSAIDA, B.DSLOCALESTOQ AS DSLESTQSAIDA FROM ( SELECT AL.CDALMOXARIFE, CDLOCALESTOQ, DSALMOXARIFE, DSLOCALESTOQ FROM ALMOXARIFADO AL, LOCALESTOQUE LE, REQUESTO RE WHERE RE.CDFILIAL = :P_CDFILIAL AND RE.NRREQUESTO = :P_NRREQUESTO AND RE.CDFILIAL = AL.CDFILIAL (+) AND RE.CDALMOXENTR = AL.CDALMOXARIFE (+) AND RE.CDFILIAL = LE.CDFILIAL (+) AND RE.CDALMOXENTR = LE.CDALMOXARIFE (+) AND RE.CDLCESTENTR = LE.CDLOCALESTOQ (+) ) A, ( SELECT AL.CDALMOXARIFE, CDLOCALESTOQ, DSALMOXARIFE, DSLOCALESTOQ FROM ALMOXARIFADO AL, LOCALESTOQUE LE, REQUESTO RE WHERE RE.CDFILIAL = :P_CDFILIAL AND RE.NRREQUESTO = :P_NRREQUESTO AND RE.CDFILIAL = AL.CDFILIAL (+) AND RE.CDALMOXSAID = AL.CDALMOXARIFE (+) AND RE.CDFILIAL = LE.CDFILIAL (+) AND RE.CDALMOXSAID = LE.CDALMOXARIFE (+) AND RE.CDLCESTSAID = LE.CDLOCALESTOQ (+) ) B";
       
        $params = array(
            'P_NRREQUESTO'=>$nrrequesto,
            'P_CDFILIAL'=>$cdfilial
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function buscaItensTransferencia($nrorg, $cdfilial,$nrlanestentr) {

        $sql = "SELECT *
                FROM ITLANCTOEST
                WHERE
                    NRORG             = :P_NRORG AND
                    CDFILIAL          = :P_CDFILIAL AND
                    NRLANCESTQ      = :P_NRLANESTENTR ";

        $params = array(
            'P_NRORG'=>$nrorg,
            'P_CDFILIAL'=>$cdfilial,
            'P_NRLANESTENTR'=>$nrlanestentr,
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function verificaReqComp($CDFILIAL, $CDFILLANCREQ, $NRLANCREQC, $NRSEQITREQC) {
        
        $sql = "SELECT NRREQUESTO
                FROM ITREQUESTO
                WHERE CDFILIAL = :P_CDFILIAL
                AND CDFILLANCREQC = :P_CDFILLANCREQ
                AND NRLANCREQC = :P_NRLANCREQC
                AND NRSEQITREQC = NVL(:P_NRSEQITREQC, NRSEQITREQC)
                AND NRLANCESTQ IS NOT NULL";
         $params = array(
            'P_CDFILIAL'=>$CDFILIAL,
            'P_CDFILLANCREQ'=>$CDFILLANCREQ,
            'P_NRLANCREQC'=>$NRLANCREQC,
            'P_NRSEQITREQC'=>$NRSEQITREQC
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateItemReqComp($CDFILIAL, $CDFILLANCREQ, $NRLANCREQC, $NRSEQITREQC) {
        
        $sql = "UPDATE ITREQUESTO
                SET NRSEQITREQC = NULL,
                CDFILLANCREQC = NULL,
                NRLANCREQC = NULL
                WHERE CDFILIAL = :P_CDFILIAL
                AND CDFILLANCREQC = :P_CDFILLANCREQ
                AND NRLANCREQC = :P_NRLANCREQC
                AND NRSEQITREQC = NVL(:P_NRSEQITREQC, NRSEQITREQC)";
         $params = array(
            'P_CDFILIAL'=>$CDFILIAL,
            'P_CDFILLANCREQ'=>$CDFILLANCREQ,
            'P_NRLANCREQC'=>$NRLANCREQC,
            'P_NRSEQITREQC'=>$NRSEQITREQC
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function verificaUltimoItemReqComp($CDFILIAL, $CDFILLANCREQ, $NRLANCREQC, $NRSEQITREQC) {
        
        $sql = "SELECT NRREQUESTO
                FROM ITREQUESTO
                WHERE CDFILIAL = :P_CDFILIAL
                AND CDFILLANCREQC = :P_CDFILLANCREQ
                AND NRLANCREQC = :P_NRLANCREQC
                AND NRSEQITREQC <> NVL(:P_NRSEQITREQC, NRSEQITREQC)";
        $params = array(
            'P_CDFILIAL'=>$CDFILIAL,
            'P_CDFILLANCREQ'=>$CDFILLANCREQ,
            'P_NRLANCREQC'=>$NRLANCREQC,
            'P_NRSEQITREQC'=>$NRSEQITREQC
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteItemReqComp($CDFILIAL, $CDFILLANCREQ, $NRLANCREQC, $NRSEQITREQC) {
         $sql = "DELETE
                FROM ITREQUESTO
                WHERE CDFILIAL = :P_CDFILIAL
                AND CDFILLANCREQC = :P_CDFILLANCREQ
                AND NRLANCREQC = :P_NRLANCREQC
                AND NRSEQITREQC = :P_NRSEQITREQC";
        $params = array(
            'P_CDFILIAL'=>$CDFILIAL,
            'P_CDFILLANCREQ'=>$CDFILLANCREQ,
            'P_NRLANCREQC'=>$NRLANCREQC,
            'P_NRSEQITREQC'=>$NRSEQITREQC
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteItlanctoest($nrorg, $cdfilial,$nrlanestentr,$nrlanestsaid) {

        $sql = "DELETE
                FROM ITLANCTOEST
                WHERE NRORG = :P_NRORG AND
                CDFILIAL    = :P_CDFILIAL AND
                (NRLANCESTQ = :P_NRLANESTENTR OR NRLANCESTQ = :P_NRLANESTSAID)";

        $params = array(
            'P_NRORG'=>$nrorg,
            'P_CDFILIAL'=>$cdfilial,
            'P_NRLANESTENTR'=>$nrlanestentr,
            'P_NRLANESTSAID'=>$nrlanestsaid,
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function deleteLanctoestoq($nrorg, $cdfilial,$nrlanestentr,$nrlanestsaid) {

        $sql = "DELETE
                FROM LANCTOESTOQ
                WHERE NRORG = :P_NRORG AND
                CDFILIAL    = :P_CDFILIAL AND
                (NRLANCESTQ = :P_NRLANESTENTR OR NRLANCESTQ = :P_NRLANESTSAID)";

        $params = array(
            'P_NRORG'=>$nrorg,
            'P_CDFILIAL'=>$cdfilial,
            'P_NRLANESTENTR'=>$nrlanestentr,
            'P_NRLANESTSAID'=>$nrlanestsaid,
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function deleteCtrlmoviestq($nrorg, $cdfilial,$nrctrlmovest) {
        $sql = "DELETE
                FROM CTRLMOVIESTQ
                WHERE NRORG = :P_NRORG AND
                CDFILIAL    = :P_CDFILIAL AND
                NRCTRLMOVEST = :P_NRCTRLMOVEST";

        $params = array(
            'P_NRORG'=>$nrorg,
            'P_CDFILIAL'=>$cdfilial,
            'P_NRCTRLMOVEST'=>$nrctrlmovest,
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletarRequisicao($CDFILIAL, $CDFILLANCREQ, $NRLANCREQC) {
        $sql = "DELETE
            FROM REQUESTO
            WHERE CDFILIAL    = :P_CDFILIAL
            AND CDFILLANCREQC = :P_CDFILLANCREQC
            AND NRLANCREQC    = :P_NRLANCREQC";
        $params = array(
            'P_CDFILIAL'=>$CDFILIAL,
            'P_CDFILLANCREQC'=>$CDFILLANCREQ,
            'P_NRLANCREQC'=>$NRLANCREQC
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateRequestoStatus($params) {
        $sql = "UPDATE REQUESTO
                   SET CDFILLANCREQC = NULL,
                       NRLANCREQC    = NULL,
                       IDREQUESTO    = :IDREQUESTO,
                       IDSTATUSREQ   = :IDSTATUSREQ
                 WHERE CDFILIAL   = :CDFILIAL
                   AND NRREQUESTO = :NRREQUESTO";

        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function updateItemRequisicao($CDFILIAL, $NRREQUESTO) {
        $sql = "UPDATE ITREQUESTO
                SET NRSEQITREQC = NULL,
                CDFILLANCREQC = NULL,
                NRLANCREQC = NULL
                WHERE CDFILIAL = :P_CDFILIAL
                AND NRREQUESTO = :P_NRREQUESTO";
         $params = array(
            'P_CDFILIAL'=>$CDFILIAL,
            'P_NRREQUESTO'=>$NRREQUESTO
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateItrequestoStatus($params) {
        $sql = "UPDATE ITREQUESTO
                   SET IDSTITREQU  = :IDSTITREQU,
                       CDFILILANC  = :CDFILILANC,
                       NRLANCESTQ  = :NRLANCESTQ,
                       NRSEQUITEM  = :NRSEQUITEM
                 WHERE CDFILIAL    = :CDFILIAL
                   AND NRREQUESTO  = :NRREQUESTO
                   AND NRSEQITEM   = NVL(:NRSEQITEM, NRSEQITEM)
                   AND (NRLANCESTQ = :OLD_NRLANCESTQ OR :OLD_NRLANCESTQ IS NULL)
                   AND CDPRODUTO   = NVL(:CDPRODUTO, CDPRODUTO)
                   AND NRORG       = :NRORG";
                   
        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
     
    public function getItensByRequisicao($params) {
        $sql = "SELECT IT.NRSEQUITEM, IT.CDPRODUTO, PR.CDPRODESTO, IT.CDFILIAL AS CDFILIMOVI,
                  IT.NRLOTEESTQ, IT.NRSUBLOTE, IT.QTREQUESTO  AS QTTOTLANCTO,
                  RE.CDALMOXSAID AS CDALMOXARIFE, RE.CDLCESTSAID AS CDLOCALESTOQ,
                  IT.IDSTITREQU, IT.QTDEVOREQU  AS QTDEVOLESTOQ, ' ' AS VRUNILANCTO
                FROM ITREQUESTO IT, PRODUTO PR, REQUESTO RE
                WHERE IT.CDFILIAL = :CDFILIAL
                  AND IT.NRORG      = :NRORG
                  AND IT.NRREQUESTO = :NRREQUESTO
                  AND IT.CDPRODUTO  = PR.CDPRODUTO
                  AND IT.NRORG      = PR.NRORG
                  AND IT.CDFILIAL   = RE.CDFILIAL
                  AND IT.NRORG      = RE.NRORG
                  AND IT.IDSTITREQU = NVL(:IDSTITREQU, IT.IDSTITREQU)
                  AND IT.NRREQUESTO = RE.NRREQUESTO
                ORDER BY IT.CDPRODUTO";

        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    public function insertRequisicaoComplementar($params) {
        $sql = "INSERT INTO REQUESTO (CDFILIAL, NRREQUESTO, DTREQUESTO, DTPREVREQU, DSREQUESTO,
                            CDSETOR, CDCENTCUST, CDOPERREQU, CDALMOXSAID, CDLCESTSAID,
                            CDALMOXENTR, CDLCESTENTR, CDFILLANCREQC, NRLANCREQC)
                   VALUES (:CDFILIAL, :NRREQUESTO, :DTREQUESTO, :DTPREVREQU, :DSREQUESTO,
                           :CDSETOR, :CDCENTCUST, :CDOPERREQU, :CDALMOXSAID, :CDLCESTSAID,
                           :CDALMOXENTR, :CDLCESTENTR, :CDFILLANCREQC, :NRLANCREQC)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function insertItrequestoComplementar($params) {
        $sql = "INSERT INTO ITREQUESTO (CDFILIAL, NRREQUESTO, CDPRODUTO, QTREQUESTO, QTDEVOREQU,
                                        IDSTITREQU, CDFILILANC, NRLANCESTQ, NRSEQUITEM, NRLOTEESTQ,
                                        NRSUBLOTE, CDFILLANCREQC, NRLANCREQC , NRSEQITREQC, NRSEQITEM)
                               VALUES (:CDFILIAL, :NRREQUESTO, :CDPRODUTO, :QTREQUESTO, :QTDEVOREQU,
                                       :IDSTITREQU, :CDFILILANC, :NRLANCESTQ, :NRSEQUITEM, :NRLOTEESTQ,
                                       :NRSUBLOTE, :CDFILLANCREQC, :NRLANCREQC, :NRSEQITREQC, :NRSEQITEM)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function getRequisicaoComplementarAberta($params) {
        $sql = "SELECT NRREQUESTO
                  FROM REQUESTO
                 WHERE CDFILLANCREQC = :CDFILLANCREQC
                   AND NRLANCREQC    = :NRLANCREQC
                   AND IDSTATUSREQ  <> 'E'";

        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetch();
    }
    
    public function getRequisicaoComplementarParameters($params) {
        $sql = "SELECT CDFILIAL,
                       NRREQUESTO,
                       DTREQUESTO,
                       DSREQUESTO,
                       IDREQUESTO,
                       DTPREVREQU,
                       CDALMOXSAID,
                       CDLCESTSAID,
                       CDALMOXENTR,
                       CDLCESTENTR,
                       CDCENTCUST,
                       CDSETOR
                  FROM REQUESTO
                 WHERE CDFILIAL   = :CDFILIMOVI
                   AND NRREQUESTO = :NRREQUESTO";

        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetch();
     }
     
    public function getDataForProduct($CDARVPROD) {
        $sql = "SELECT CDPRODESTO 
                  FROM PRODUTO 
                 WHERE CDARVPROD = :CDARVPROD";
        
        $params = array(
            'CDARVPROD'=>$CDARVPROD
        );
        
        $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetch();
        
     }
     
    public function getProdutoTabela($parameters){
        $sql = "";
        if(isset($parameters["P_CDARVPROD"])){
           $sql = "SELECT DISTINCT PF.CDFILIAL,
                        P.CDPRODUTO,
                        P.CDARVPROD,
                        P.NMPRODUTO,
                        P.SGUNIDADE,
                        P.VRFATOCONV,
                        P.CDPRODESTO AS CDPRODMOVI,
                        P.NRORG,
                        ' ' AS CDALMOXARIFE,
                        ' ' AS CDLOCALESTOQ,
                        ' ' AS NRLOTEESTQ,
                        ' ' AS NRSUBLOTE,
                        CUSTO_PRODUTO_LCEST( :P_CDFILIAL, P.CDPRODESTO, '03', :P_DTMOVIESTQ, SYSDATE, 
                        :P_CDALMOXARIFE, :P_CDLOCALESTOQ, :P_NRLOTEESTQ, :P_NRSUBLOTE) AS VRUNILANCTO,
                        0 AS VRTOTLANCTO,
                        0 AS VRLANCTOEST,
                        CUSTO_PRODUTO_LCEST( :P_CDFILIAL, P.CDPRODESTO, '02', :P_DTMOVIESTQ, SYSDATE, 
                        :P_CDALMOXARIFE, :P_CDLOCALESTOQ, :P_NRLOTEESTQ, :P_NRSUBLOTE) AS VRUNITBRUT,
                        0 AS QTTOTLANCTO
                    FROM
                        PRODUTO P JOIN
                        PRODFILI PF ON P.CDPRODUTO = PF.CDPRODUTO
                    WHERE
                        P.CDARVPROD = :P_CDARVPROD AND
                        PF.CDFILIAL = :P_CDFILIAL"; 
        }else if(isset($parameters["P_CDBARPRODUTO"])){
            $sql = "SELECT DISTINCT PF.CDFILIAL,
                            P.CDPRODUTO,
                            P.CDARVPROD,
                            P.NMPRODUTO,
                            P.SGUNIDADE,
                            P.VRFATOCONV,
                            P.CDPRODESTO AS CDPRODMOVI,
                            P.NRORG,
                            ' ' AS CDALMOXARIFE,
                            ' ' AS CDLOCALESTOQ,
                            ' ' AS NRLOTEESTQ,
                            ' ' AS NRSUBLOTE,
                            CUSTO_PRODUTO_LCEST( :P_CDFILIAL, P.CDPRODESTO, '03', :P_DTMOVIESTQ, SYSDATE, 
                            :P_CDALMOXARIFE, :P_CDLOCALESTOQ, :P_NRLOTEESTQ, :P_NRSUBLOTE) AS VRUNILANCTO,
                            0 AS VRTOTLANCTO,
                            0 AS VRLANCTOEST,
                            CUSTO_PRODUTO_LCEST( :P_CDFILIAL, P.CDPRODESTO, '02', :P_DTMOVIESTQ, SYSDATE, 
                            :P_CDALMOXARIFE, :P_CDLOCALESTOQ, :P_NRLOTEESTQ, :P_NRSUBLOTE) AS VRUNITBRUT,
                            0 AS QTTOTLANCTO
                      FROM PRODUTO P
                      JOIN PRODFILI PF 
                        ON P.CDPRODUTO = PF.CDPRODUTO
                     WHERE P.CDBARPRODUTO = :P_CDBARPRODUTO
                       AND PF.CDFILIAL = :P_CDFILIAL
                     UNION
                    SELECT  PF.CDFILIAL,
                            P.CDPRODUTO,
                            P.CDARVPROD,
                            P.NMPRODUTO,
                            P.SGUNIDADE,
                            P.VRFATOCONV,
                            P.CDPRODESTO AS CDPRODMOVI,
                            P.NRORG,
                            ' ' AS CDALMOXARIFE,
                            ' ' AS CDLOCALESTOQ,
                            ' ' AS NRLOTEESTQ,
                            ' ' AS NRSUBLOTE,
                            CUSTO_PRODUTO_LCEST( :P_CDFILIAL, P.CDPRODESTO, '03', :P_DTMOVIESTQ, SYSDATE, 
                            :P_CDALMOXARIFE, :P_CDLOCALESTOQ, :P_NRLOTEESTQ, :P_NRSUBLOTE) AS VRUNILANCTO,
                            0 AS VRTOTLANCTO,
                            0 AS VRLANCTOEST,
                            CUSTO_PRODUTO_LCEST( :P_CDFILIAL, P.CDPRODESTO, '02', :P_DTMOVIESTQ, SYSDATE, 
                            :P_CDALMOXARIFE, :P_CDLOCALESTOQ, :P_NRLOTEESTQ, :P_NRSUBLOTE) AS VRUNITBRUT,
                            0 AS QTTOTLANCTO
                      FROM PRODUTO P
                      LEFT JOIN CDBARRAPROD CDBP
                        ON P.CDPRODUTO = CDBP.CDPRODUTO
                      LEFT JOIN PRODFILI PF 
                        ON P.CDPRODUTO = PF.CDPRODUTO
                     WHERE CDBP.CDBARRAPROD = :P_CDBARPRODUTO
                       AND PF.CDFILIAL = :P_CDFILIAL"; 
            
        } else{
            $sql = "SELECT DISTINCT PF.CDFILIAL,
                        P.CDPRODUTO,
                        P.CDARVPROD,
                        P.NMPRODUTO,
                        P.SGUNIDADE,
                        P.VRFATOCONV,
                        P.CDPRODESTO AS CDPRODMOVI,
                        P.NRORG,
                        ' ' AS CDALMOXARIFE,
                        ' ' AS CDLOCALESTOQ,
                        ' ' AS NRLOTEESTQ,
                        ' ' AS NRSUBLOTE,
                        CUSTO_PRODUTO_LCEST( :P_CDFILIAL, P.CDPRODESTO, '03', :P_DTMOVIESTQ, SYSDATE, 
                        :P_CDALMOXARIFE, :P_CDLOCALESTOQ, :P_NRLOTEESTQ, :P_NRSUBLOTE) AS VRUNILANCTO,
                        0 AS VRTOTLANCTO,
                        0 AS VRLANCTOEST,
                        CUSTO_PRODUTO_LCEST( :P_CDFILIAL, P.CDPRODESTO, '02', :P_DTMOVIESTQ, SYSDATE, 
                        :P_CDALMOXARIFE, :P_CDLOCALESTOQ, :P_NRLOTEESTQ, :P_NRSUBLOTE) AS VRUNITBRUT,
                        0 AS QTTOTLANCTO
                    FROM
                        PRODUTO P JOIN
                        PRODFILI PF ON P.CDPRODUTO = PF.CDPRODUTO
                    WHERE
                        P.CDPRODUTO = :P_CDPRODUTO AND
                        PF.CDFILIAL = :P_CDFILIAL"; 
        }
        
        
        $std = $this->connection->prepare($sql);
        $std->execute($parameters);
        $result = $std->fetchAll();
        if(isset($result[0])){
            return $result[0];
        } else{
            return null;
        }
    }
    

}