CREATE OR REPLACE PROCEDURE DELETA_MAPA(
   P_NRSEQUMAPAPU IN MAPAAPURAC.NRSEQUMAPAPU%TYPE,
   P_BOBLOQ       IN MAPAAPURAC.IDBLOQMAPAPU%TYPE)
AS
   V_IDNFFORAPERAPU    VARCHAR2(01);
   V_IDNFFORAPERAPUIMP VARCHAR2(01);
BEGIN
   
   /******** Parmetro Vincula NF Fora do Perodo ********/
   BEGIN
      SELECT IDNFFORAPERAPU
        INTO V_IDNFFORAPERAPU
        FROM PARAMFISCAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_IDNFFORAPERAPU := 'N';
   END;

   /******** Parmetro Vincula NF Fora do Perodo por Imposto ********/
   BEGIN
      SELECT MAX(IDNFFORAPERAPU)
        INTO V_IDNFFORAPERAPUIMP
        FROM IMPOSTO I, MAPAAPURAC M
       WHERE M.NRSEQUMAPAPU = P_NRSEQUMAPAPU
         AND M.CDIMPOSTO    = I.CDIMPOSTONFE;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_IDNFFORAPERAPUIMP := '';
   END;

   IF V_IDNFFORAPERAPUIMP <> 'I' THEN
      V_IDNFFORAPERAPU := V_IDNFFORAPERAPUIMP;
   END IF;

   /******** Limpa a Nota Fiscal ********/
   UPDATE NOTAFISCAL
      SET NRSEQUMAPAPUNF = NULL
    WHERE NRSEQUMAPAPUNF = P_NRSEQUMAPAPU;

   /******** Deleta as notas relacionadas na apurao dos impostos federais (INSS) ********/
   DELETE FROM RELACMAPAIMPONF
    WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;

   /******** Limpar os Itens de Compensaes para os Impostos Federais ********/
   DELETE FROM ITDETAPUCONTR
    WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;

   /******** Deleta o detalhamento (Aba Outros Valores) dos Impostos Federais ********/
   DELETE FROM MAPAAPUIMPOFED
    WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;

   /******** Limpa os Impostos ********/
   IF V_IDNFFORAPERAPU = 'S' THEN
      /******** Imposto Apurao, Carga Tributria e Compensaes dos Impostos Federais
                Considerando Vincula NF Fora do Perodo ********/
      /******** ImpostoNF ********/
      UPDATE IMPOSTONF
         SET NRSEQMAPOIMP = NULL
       WHERE NRSEQMAPOIMP = P_NRSEQUMAPAPU;
      /******** Regime de Caixa, quando utiliza a tabela do Financeiro ********/
      UPDATE IMPBAIXAREC
         SET NRSEQMAPOIMP = NULL
       WHERE NRSEQMAPOIMP = P_NRSEQUMAPAPU;

      /******** Imposto do Mapa e Imposto Relacionado para Apurao
                Considerando Vincula NF Fora do Perodo ********/
       /******** ImpostoNF ********/
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPU = NULL
       WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;
      /******** Regime de Caixa, quando utiliza a tabela do Financeiro ********/
      UPDATE IMPBAIXAREC
         SET NRSEQUMAPAPU = NULL
       WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;

   ELSE
      /******** Imposto Apurao, Carga Tributria e Compensaes dos Impostos Federais
                Limpando Vincula NF Fora do Perodo ********/
      /******** ImpostoNF ********/
      UPDATE IMPOSTONF
         SET NRSEQMAPOIMP = NULL,
             DTREFMAPAPU  = NULL
       WHERE NRSEQMAPOIMP = P_NRSEQUMAPAPU;
       /******** Regime de Caixa, quando utiliza a tabela do Financeiro ********/
       UPDATE IMPBAIXAREC
          SET NRSEQMAPOIMP = NULL,
              DTREFMAPAPU  = NULL
        WHERE NRSEQMAPOIMP = P_NRSEQUMAPAPU;

      /******** Imposto do Mapa e Imposto Relacionado para Apurao
                Limpando Vincula NF Fora do Perodo ********/
      /******** ImpostoNF ********/
      UPDATE IMPOSTONF
         SET NRSEQUMAPAPU = NULL,
             DTREFMAPAPU  = NULL
       WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;
      /******** Regime de Caixa, quando utiliza a tabela do Financeiro ********/
      UPDATE IMPBAIXAREC
         SET NRSEQUMAPAPU = NULL,
             DTREFMAPAPU  = NULL
       WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;

   END IF;

   /******** Parmetros para gerao da GIA SC  ********/
   DELETE FROM PARGERGIASC
    WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;

   IF P_BOBLOQ = 'N' THEN
      /******** Deleta os Outros Valores na Guia do ST ********/
      DELETE FROM AJUSTMAPAAPURSG
       WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;

      /******** Guia de Substituio Tributria ********/
      DELETE FROM MAPAAPURESTADO
       WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;

      /******** Pr-Validao do SPED Fiscal ********/
      DELETE FROM ERRONFPREVALID
       WHERE (CDFILIAL, NRLANCTONF) IN (SELECT CDFILIAL, NRLANCTONF
                                          FROM NFPREVALIDFIS
                                         WHERE NRSEQUMAPAPUNFP = P_NRSEQUMAPAPU);

      DELETE FROM NFPREVALIDFIS
       WHERE NRSEQUMAPAPUNFP = P_NRSEQUMAPAPU;

      /******** Estorno de Crdito ********/
      FOR C_ESTORNO IN (SELECT NRSEQESTCRED, CDFILIALENTR,   NRLANCTONFENTR,  NRSEQITPRODENTR,
                               CDFILIALSAID, NRLANCTONFSAID, NRSEQITPRODSAID, QTUTILIZADA
                          FROM ESTORNOCRED
                         WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU) LOOP      

         /******** Atualiza o saldo na ItemProduto ********/
         UPDATE ITEMPRODUTO
            SET QTSALDOESTCRED = QTSALDOESTCRED + C_ESTORNO.QTUTILIZADA,
                IDUTILESTCRED  = DECODE((QTSALDOESTCRED + C_ESTORNO.QTUTILIZADA),QTITEMPROD,'N','S')
          WHERE CDFILIAL     = C_ESTORNO.CDFILIALENTR
            AND NRLANCTONF   = C_ESTORNO.NRLANCTONFENTR
            AND NRSEQITPROD  = C_ESTORNO.NRSEQITPRODENTR;

         UPDATE ITEMPRODUTO
            SET QTSALDOESTCRED = QTSALDOESTCRED + C_ESTORNO.QTUTILIZADA,
                IDUTILESTCRED  = DECODE((QTSALDOESTCRED + C_ESTORNO.QTUTILIZADA),QTITEMPROD,'N','S')
          WHERE CDFILIAL     = C_ESTORNO.CDFILIALSAID
            AND NRLANCTONF   = C_ESTORNO.NRLANCTONFSAID
            AND NRSEQITPROD  = C_ESTORNO.NRSEQITPRODSAID;

         /******** Deleta o relacionamento do estorno ********/
         DELETE FROM ESTORNOCRED
          WHERE NRSEQESTCRED = C_ESTORNO.NRSEQESTCRED;

      END LOOP;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('DELETA_MAPA','5.85.xxx'); END;
/
